%global srcname rdflib

Summary:        Python library for working with RDF
Name:           python-%{srcname}
Version:        6.2.0
Release:        5%{?dist}
License:        BSD-3-Clause
URL:            https://github.com/RDFLib/%{srcname}
Source0:        %{pypi_source}

BuildArch:      noarch
BuildRequires:  python%{python3_pkgversion}-devel python%{python3_pkgversion}-setuptools
%{?python_enable_dependency_generator}

%description
RDFLib is a pure Python package for working with RDF.


%package -n python%{python3_pkgversion}-%{srcname}
Summary:        %{summary}

%description -n python%{python3_pkgversion}-%{srcname}
RDFLib is a pure Python package for working with RDF.
RDFLib contains most things you need to work with RDF, including:
1. parsers and serializers for RDF/XML, N3, NTriples, N-Quads, Turtle, TriX, Trig and JSON-LD
2. a Graph interface which can be backed by any one of a number of Store implementations
3. store implementations for in-memory, persistent on disk (Berkeley DB) and remote SPARQL endpoints
4. a SPARQL 1.1 implementation - supporting SPARQL 1.1 Queries and Update statements
5. SPARQL function extension mechanisms


%prep
%autosetup -p1 -n %{srcname}-%{version}

%generate_buildrequires
%pyproject_buildrequires -x tests


%build
%py3_build


%install
%py3_install
chmod +x %{buildroot}%{python3_sitelib}/rdflib/plugins/parsers/ntriples.py
chmod +x %{buildroot}%{python3_sitelib}/rdflib/plugins/parsers/notation3.py
chmod +x %{buildroot}%{python3_sitelib}/rdflib/tools/rdfpipe.py
chmod +x %{buildroot}%{python3_sitelib}/rdflib/extras/infixowl.py \
         %{buildroot}%{python3_sitelib}/rdflib/extras/external_graph_libs.py

for lib in %{buildroot}%{python3_sitelib}/rdflib/extras/describer.py \
    %{buildroot}%{python3_sitelib}/rdflib/plugins/parsers/pyRdfa/extras/httpheader.py; do
 sed '1{\@^#!/usr/bin/env python@d}' $lib > $lib.new &&
 touch -r $lib $lib.new &&
 mv $lib.new $lib
done

sed -i '1s=^#!/usr/bin/\(python\|env python\).*=#!%{__python3}='  \
    %{buildroot}%{python3_sitelib}/rdflib/extras/infixowl.py \
    %{buildroot}%{python3_sitelib}/rdflib/extras/external_graph_libs.py \
    %{buildroot}%{python3_sitelib}/rdflib/plugins/parsers/ntriples.py \
    %{buildroot}%{python3_sitelib}/rdflib/tools/rdfpipe.py \
    %{buildroot}%{python3_sitelib}/rdflib/plugins/parsers/notation3.py


%check
# some testcases need network which is not available in mock.
%{__python3} -m pytest || :


%files -n python3-%{srcname}
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/csv2rdf
%{_bindir}/rdf2dot
%{_bindir}/rdfgraphisomorphism
%{_bindir}/rdfpipe
%{_bindir}/rdfs2dot
%{python3_sitelib}/%{srcname}
%{python3_sitelib}/%{srcname}-%{version}-py%{python3_version}.egg-info


%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.2.0-5
- Rebuilt for loongarch release

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.2.0-4
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.2.0-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.2.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Sun Apr 23 2023 rockerzhu <rockerzhu@tencent.com> - 6.2.0-1
- Initial build.
